package net.metaunix.services;

import java.util.Arrays;
import java.util.List;
import javafx.concurrent.ScheduledService;
import javafx.concurrent.Task;
import oshi.SystemInfo;
import oshi.hardware.CentralProcessor;
import oshi.hardware.GlobalMemory;
import oshi.hardware.GraphicsCard;
import oshi.hardware.HardwareAbstractionLayer;
import oshi.hardware.Sensors;
import oshi.software.os.OperatingSystem;

import net.metaunix.SysInfo;

public class UpdateSystemInfoService extends ScheduledService<Void> {

  private static int counter = 0;

  @Override
  protected Task<Void> createTask() {
    return new Task<>() {

      @Override
      protected Void call() throws Exception {
        UpdateSystemInfoService.counter++;

        SystemInfo si = new SystemInfo();
        OperatingSystem os = si.getOperatingSystem();
        SysInfo.osString = String.valueOf(UpdateSystemInfoService.counter) + " " + String.valueOf(os);

        HardwareAbstractionLayer hal = si.getHardware();
        Sensors sensors = hal.getSensors();
        SysInfo.cpuTemp = sensors.getCpuTemperature();
        CentralProcessor cpu = hal.getProcessor();
        SysInfo.cpuMaxFreq = cpu.getMaxFreq();
        SysInfo.cpuUsage = (cpu.getSystemLoadAverage(3)[0] / cpu.getLogicalProcessorCount());

        GlobalMemory memory = hal.getMemory();
        SysInfo.memoryTotal = memory.getTotal();
        SysInfo.memoryUsed = (SysInfo.memoryTotal - memory.getAvailable());

        List<GraphicsCard> gpus = hal.getGraphicsCards();
        SysInfo.gpuName = gpus.get(0).getName();

        long[] freqs = cpu.getCurrentFreq();
        Arrays.sort(freqs);
        SysInfo.cpuFreq = freqs[freqs.length - 1];

        return null;
      }

    };
  }

}
